"use strict";

require("core-js/modules/es.weak-map.js");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.AlertMessagesContext = void 0;
exports.default = AlertMessagesProvider;
require("core-js/modules/web.dom-collections.iterator.js");
var _react = _interopRequireWildcard(require("react"));
var _lodash = _interopRequireDefault(require("lodash"));
var _AlertMessages = _interopRequireDefault(require("./components/AlertMessages"));
var _const = require("./const");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
const AlertMessagesContext = /*#__PURE__*/(0, _react.createContext)({
  postAlertMessage: message => {}
});
exports.AlertMessagesContext = AlertMessagesContext;
function AlertMessagesProvider(_ref) {
  let {
    children
  } = _ref;
  const [alertMessages, setAlertMessages] = _react.default.useState([]);
  const _doesExistingAlertIsInProgress = (0, _react.useCallback)(existingMessage => {
    return existingMessage && existingMessage.type === _const.TYPE_IN_PROGRESS;
  }, []);
  const _isIndefiniteInProgressAlert = (0, _react.useCallback)(message => {
    return message.type === _const.TYPE_IN_PROGRESS && message.timeout === -1;
  }, []);
  const _clearAlertMessageWithKey = (0, _react.useCallback)((messages, messageKey) => {
    const messagesToClear = messages.filter(msg => msg.key === messageKey && msg.clearMessageTimeoutReference !== null);
    messagesToClear.forEach(messageToClear => {
      clearTimeout(messageToClear.clearMessageTimeoutReference);
    });
    return messages.filter(msg => msg.key !== messageKey);
  }, []);
  const _isDoneMessageForPendingAlert = (0, _react.useCallback)((message, existingMessage) => {
    var _existingMessage$_pen;
    return (message.type === _const.TYPE_SUCCESS || message.type === _const.TYPE_FAILED) && existingMessage && ((_existingMessage$_pen = existingMessage._pendingRequests) !== null && _existingMessage$_pen !== void 0 ? _existingMessage$_pen : 0) > 1;
  }, []);
  const _createClearMessageJob = (0, _react.useCallback)(message => {
    if (message.timeout === -1) {
      return undefined;
    }
    return setTimeout(() => {
      setAlertMessages(messages => messages.filter(alertMessage => alertMessage.key !== message.key));
    }, message.timeout || 2000);
  }, [setAlertMessages]);
  const _checkForPendingMessage = (0, _react.useCallback)((messages, message) => {
    const existingMessage = messages.filter(msg => msg.key === message.key)[0];
    if (_isIndefiniteInProgressAlert(message)) {
      if (_doesExistingAlertIsInProgress(existingMessage)) {
        var _existingMessage$_pen2;
        existingMessage._pendingRequests = ((_existingMessage$_pen2 = existingMessage._pendingRequests) !== null && _existingMessage$_pen2 !== void 0 ? _existingMessage$_pen2 : 0) + 1;
        return messages;
      }
      message._pendingRequests = 1;
      return [..._clearAlertMessageWithKey(messages, message.key), message];
    }
    if (_isDoneMessageForPendingAlert(message, existingMessage)) {
      var _existingMessage$_pen3;
      existingMessage._pendingRequests = ((_existingMessage$_pen3 = existingMessage._pendingRequests) !== null && _existingMessage$_pen3 !== void 0 ? _existingMessage$_pen3 : 0) - 1;
      return messages;
    }
  }, [_isIndefiniteInProgressAlert, _doesExistingAlertIsInProgress, _clearAlertMessageWithKey, _isDoneMessageForPendingAlert]);
  const postAlertMessage = (0, _react.useCallback)(message => {
    var _message$key;
    message.key = (_message$key = message.key) !== null && _message$key !== void 0 ? _message$key : "alert-".concat(Date.now());
    setAlertMessages(messages => {
      const updatedMessages = _checkForPendingMessage(messages, message);
      if (updatedMessages) {
        return _lodash.default.cloneDeep(updatedMessages);
      }
      message.clearMessageTimeoutReference = _createClearMessageJob(message);
      return [..._clearAlertMessageWithKey(messages, message.key), message];
    });
  }, [setAlertMessages, _checkForPendingMessage, _createClearMessageJob, _clearAlertMessageWithKey]);
  const clearAlertMessage = (0, _react.useCallback)(messageKey => {
    setAlertMessages(messages => _clearAlertMessageWithKey(messages, messageKey));
  }, [setAlertMessages, _clearAlertMessageWithKey]);
  return /*#__PURE__*/_react.default.createElement(AlertMessagesContext.Provider, {
    value: {
      postAlertMessage
    }
  }, /*#__PURE__*/_react.default.createElement(_AlertMessages.default, {
    messages: alertMessages,
    clearAlertMessage: clearAlertMessage
  }), children);
}